@@ -1,11 +1,11 @@
 # gitpylib - a Python library for Git.
-# Copyright (c) 2013  Santiago Perez De Rosso.
-# Licensed under GNU GPL, version 2.
+# Licensed under GNU GPL v2.
 
 """Common methods used accross the gitpylib."""
 
 
 import os
+import shlex
 import subprocess
 import sys
 
@@ -18,6 +18,21 @@ with tempfile.NamedTemporaryFile() as f_tmp:
   FS_CASE_SENSITIVE = not os.path.exists(f_tmp.name.upper())
 
 
+class UnexpectedOutputError(Exception):
+
+  def __init__(self, cmd, out, err=None):
+    super(UnexpectedOutputError, self).__init__()
+    self.cmd = cmd
+    self.out = out
+    self.err = err
+
+  def __str__(self):
+    err = 'err was:\n{0}\n' if self.err else ''
+    return (
+        'Unexpected output from cmd {0}, out was:\n{1}\n{2}'.format(
+            self.cmd, self.out, err))
+
+
 def safe_git_call(cmd):
   ok, out, err = git_call(cmd)
   if ok:
@@ -27,8 +42,8 @@ def safe_git_call(cmd):
 
 def git_call(cmd):
   p = subprocess.Popen(
-      'git %s' % cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
-      shell=True)
+      shlex.split('git %s' % cmd),
+      stdout=subprocess.PIPE, stderr=subprocess.PIPE)
   out, err = p.communicate()
   # Python 2/3 compatibility.
   if sys.version > '3':
